==> myfaces-tobago-5.15.0-source-release.zip: tobago-5.15.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISplitLayout.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.component;

import org.apache.myfaces.tobago.apt.annotation.Preliminary;
import org.apache.myfaces.tobago.layout.AlignItems;
import org.apache.myfaces.tobago.layout.JustifyContent;

import javax.faces.event.ListenerFor;
import javax.faces.event.PostAddToViewEvent;

/**
 * <p>
 * WARNING: This component is preliminary and may be changed without a major release.
 * </p>
 *
 * {@link org.apache.myfaces.tobago.internal.taglib.component.SplitLayoutTagDeclaration}
 */
@Preliminary
@ListenerFor(systemEventClass = PostAddToViewEvent.class)
public abstract class AbstractUISplitLayout extends AbstractUIFlexLayout {

  public static final String COMPONENT_FAMILY = "org.apache.myfaces.tobago.SplitLayout";

  // TODO
  private String submittedLayout;

  public AlignItems getAlignItems() {
    return null; // TBD
  }

  public JustifyContent getJustifyContent() {
    return null; // TBD
  }

}

==> myfaces-tobago-6.4.0-source-release.zip: tobago-6.4.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISplitLayout.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.component;

import org.apache.myfaces.tobago.apt.annotation.Preliminary;
import org.apache.myfaces.tobago.layout.AlignItems;
import org.apache.myfaces.tobago.layout.JustifyContent;

import jakarta.faces.event.ListenerFor;
import jakarta.faces.event.PostAddToViewEvent;

/**
 * <p>
 * WARNING: This component is preliminary and may be changed without a major release.
 * </p>
 *
 * {@link org.apache.myfaces.tobago.internal.taglib.component.SplitLayoutTagDeclaration}
 */
@Preliminary
@ListenerFor(systemEventClass = PostAddToViewEvent.class)
public abstract class AbstractUISplitLayout extends AbstractUIFlexLayout {

  public static final String COMPONENT_FAMILY = "org.apache.myfaces.tobago.SplitLayout";

  // TODO
  private String submittedLayout;

  public AlignItems getAlignItems() {
    return null; // TBD
  }

  public JustifyContent getJustifyContent() {
    return null; // TBD
  }

}
